@@ -28,7 +28,7 @@
 
 
   (if (not (equal? #f (object-property symbol 'translation-doc)))
-      (ly:error (_ "symbol ~S redefined" symbol)))
+      (ly:error (_ "symbol ~S redefined") symbol))
 
   (set-object-property! symbol 'translation-type? type?)
   (set-object-property! symbol 'translation-doc description)
@@ -64,7 +64,7 @@ numbers.  Can be @code{numbers} for going back to the same number or
 @code{numbers-with-letters} for going back to the same number with letter
 suffixes.  No setting will not go back in measure-number time.")
      (alternativeRestores ,symbol-list? "Timing variables that are
-restored to their value at the end of the first alternative in
+restored to their value at the start of the first alternative in
 subsequent alternatives.")
      (associatedVoice ,string? "Name of the context (see
 @code{associatedVoiceType} for its type, usually @code{Voice}) that
